#
# spec file for package perl-Convert-UUlib
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           perl-Convert-UUlib
Version:        1.8
Release:        1.17
#Upstream: CHECK(Artistic-1.0 or GPL-1.0-or-later)
%define cpan_name Convert-UUlib
Summary:        Decode uu/xx/b64/mime/yenc/etc-encoded data from a massive number of files
License:        GPL-1.0-or-later
Group:          Development/Libraries/Perl
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/M/ML/MLEHMANN/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Canary::Stability)
BuildRequires:  perl(common::sense) >= 3.74
Requires:       perl(common::sense) >= 3.74
%{perl_requires}
# MANUAL BEGIN
Provides:       p_conulb
Obsoletes:      p_conulb
# MANUAL END

%description
This module started as an interface to the uulib/uudeview library by Frank
Pilhofer that can be used to decode all kinds of usenet (and other) binary
messages.

After upstream abondoned the project, th library was continuously bugfixed
and improved in this module, with major focuses on security fixes,
correctness and speed (that does not mean that this library is considered
safe with untrusted data, but it surely is safer than the poriginal
uudeview).

Read the file doc/library.pdf from the distribution for in-depth
information about the C-library used in this interface, and the rest of
this document and especially the non-trivial decoder program at the end.

%prep
%setup -q -n %{cpan_name}-%{version}
find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -name "configure" -print0 | xargs -0 chmod 644

%build
perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
make %{?_smp_mflags}

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%defattr(-,root,root,755)
%doc Changes doc example-decoder README
%license COPYING COPYING.Artistic COPYING.GNU

%changelog
* Thu Dec 17 2020 Tina Müller <timueller+perl@suse.de>
- updated to 1.8
  see /usr/share/doc/packages/perl-Convert-UUlib/Changes
  TODO: biggest timesinks: FP_fgets/getc_unlocked overall, UUInsertPartToList dominates large loads due to O(n**2) search
  1.8  Thu Dec 17 02:23:53 CET 2020
  - no bugfixes in this release due to lack of known bugs, but the major changes
    in this release might have introduced new bugs, so watch out.
  - update large decoder example to disable OPT_AUTOCHK and use Smerge -1.
  - some micro-optimisations.
  - avoid costly string comparisons by comparing hashes when isnerting items,
    which speeds up insertion by a constant factor.
  - improve uulist (and other) structure layout and size.
  - reverse the order of file list items, which heuristically improves
    match speed with large usenet file lists.
  - use getc instead of fgetc, which makes no difference on gnu/linux.
  - clean up _FP symbol names toi not start with an underscore.
  - use feof_unlocked and ferror_unlocked.
  - implement a faster ascii-only strnicmp.
  - misc very minor code improvements.
  - remove quite a bit of pre-posix/dos/etc. cruft.
  - use flockfile, if available, for a potential but small
    speed gain.
  - speed up inner yenc decoder loop.
  - kentnl said that this module should no longer claim to be a simple
    interface to uulib, as the bunndled copy is now better maintained
    than the original upstream library.
* Tue Mar 17 2020 <timueller+perl@suse.de>
- updated to 1.71
  see /usr/share/doc/packages/perl-Convert-UUlib/Changes
  1.71 Tue Mar 17 00:54:06 CET 2020
  - backport to c89 (patch by Paul Howarth).
* Sun Mar  1 2020 <timueller+perl@suse.de>
- updated to 1.7
  see /usr/share/doc/packages/perl-Convert-UUlib/Changes
  1.7  Sat Feb 29 22:07:54 CET 2020
  - new function: GetFileList.
  - experimental perlmulticore support (see manpage).
  - Initialize is now a NOP and CleanUp automatically initializes again.
  - updated example decoder and documentation a bit.
  - include ecb.h to deal with compiler builtins and endianness.
  - some further µ-optimisations in hot code, especially for yEnc.
  - replace crc32 function by slice-by-16 version by Stephan Brumme,
    which should speed up yEnc en-/decoding.
  - yEnc: do not calculate two crcs per part, instead, combine
    the part crcs together to form the file crc.
  - yEnc: allow pcrc= in addition to pcrc32= for yenc trailers, as
    some draft mentions both and it is actually in active use.
  - yEnc: ignore crc32= on multiparts, except on the last part,
    which avoids spurious corruption warnings.
  - be more precise in documenting code licenses in COPYING.
  - convert constant creation to the method I normally use.
  - use common::sense.
* Tue Feb 18 2020 <timueller+perl@suse.de>
- updated to 1.62
  see /usr/share/doc/packages/perl-Convert-UUlib/Changes
  1.62 Mon Feb 17 23:19:42 CET 2020
  - major performance improvement by simplifying code in _FP_gets
    to not use fscanf. This might slow things down on platforms
    with very slow fgetc.
  1.61 Sun Feb  9 18:38:29 CET 2020
  - lint uulib: fix some format string type mismatches
    and some other minor issues.
* Sat Nov  9 2019 <tina.mueller@suse.com>
- Add manual license GPL-1.0-or-later to cpanspec.yml (see COPYING file in
  the source)
* Fri Oct 25 2019 Tina Mueller <tina.mueller@suse.com>
- Regenerate spec with newest cpanspec
  * Add manual dependencies to cpanspec.yml
* Fri Oct 25 2019 <timueller+perl@suse.de>
- updated to 1.6
  see /usr/share/doc/packages/perl-Convert-UUlib/Changes
  1.6  Thu Oct 24 17:11:54 CEST 2019
  - fix heap overflow (testcase by Noel Duffy, reported
    by Robert Scheck). The defense-in-depth mechanism based
    on mmap should make this unexploitable for other than denial
    of service, on systems supporting mmap/mprotect.
* Tue Sep 25 2018 pmonrealgonzalez@suse.com
- update to 1.4
  - fix a heap overflow (testcase by Krzysztof Wojtaś).
  - on systems that support it (posix + mmap + map_anonymous),
    allocate all dynamic areas via mmap and put four guard
    pages around them, to catch similar heap overflows
    safely in the future.
  - find a safer way to pass in CC/CFLAGS to uulib.
  - added stability canary support.
* Wed Oct  8 2014 jengelh@inai.de
- Use source URLs, and remove old specfile tags and sections.
* Fri Nov 18 2011 coolo@suse.com
- use original .tar.gz
* Mon May 30 2011 vcizek@novell.com
- update to 1.4
  - avoid a classical buffer overflow in case a progress
    message is too long.
  - this release adds depdencies for snprintf/vsnprintf.
  - some uuencode encoders do not generate a final "space" line
    before the "end" marker, so do not rely on the line to be there.
* Thu Dec 16 2010 anicka@suse.cz
- update to 1.34
  * fix a one-byte-past-end-write buffer overflow in UURepairData
  (reported, analysed and testcase provided by Marco Walther).
  * quoted-printable decoding was completely broken, try a fix.
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Mon Nov 29 2010 coolo@novell.com
- remove /var/adm/perl-modules
* Tue Oct 19 2010 coolo@novell.com
- add perl as explicit buildrequire
* Sun Feb 14 2010 coolo@novell.com
- update to 1.33
  * many changes in the last 5 years, see Changes
* Sun Jan 10 2010 jengelh@medozas.de
- enable parallel build
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Apr 15 2005 schubi@suse.de
- update to most recent version 1.051
* Fri Feb 27 2004 choeger@suse.de
- update to most recent version 1.0
* Sun Jan 11 2004 adrian@suse.de
- add %%defattr
* Fri Aug 22 2003 mjancar@suse.cz
- require the perl version we build with
* Thu Jul 17 2003 choeger@suse.de
- use install_vendor and new %%perl_process_packlist macro
* Tue Jun 17 2003 choeger@suse.de
- updated filelist
- update to version 0.31
* Mon May 19 2003 choeger@suse.de
- remove installed (but unpackaged) file perllocal.pod
* Mon Aug  5 2002 link@suse.de
- updated to 0.213
- overhauled spec file
* Tue Jul  2 2002 mls@suse.de
- remove race in .packlist generation
* Sun Jan 13 2002 link@suse.de
- update to v0.201
* Wed Nov 15 2000 choeger@suse.de
- long package name
- buildroot
* Wed Jul 19 2000 choeger@suse.de
- first package, v0.11
